@@ -5,6 +5,7 @@ import requests
 
 from .common import getToken
 from .Task import Task
+from .saving.saving import determine_model
 from .web.urls import RETRIEVE_MODEL_URL, HASH_URL, COMPILE_URL
 from .saving import save_model
 
@@ -21,6 +22,8 @@ def compile(model, input_shape, library, model_label, asynchronous=False):
     if bson.ObjectId.is_valid(model):
         return model
     print("Saving model locally.")
+    if library == "":
+        library = determine_model(model)
     file_path = save_model(model, library)
     print("Model saved locally.")
     with open(file_path, "rb") as file:
