@@ -66,3 +66,24 @@ def save_data(data):
         np.savez_compressed(file, data)
     file.seek(0)
     return file
+
+
+def determine_model(model):
+    try:
+        from torch import nn
+        if isinstance(model, nn.Module):
+            return "pytorch"
+    finally:
+        pass
+    try:
+        from tensorflow.keras import Model
+        if isinstance(model, Model):
+            return "TF"
+    finally:
+        pass
+    try:
+        import mxnet
+        if isinstance(model, mxnet.gluon.nn.Block):
+            return "mxnet"
+    finally:
+        return ""
